test package — gcmpy documentation

# test package

## Submodules

## test.test_gcm_algorithm module

class test.test_gcm_algorithm.GCM_algorithm_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_manual_single_topology()
  test_marginal_JDD_single_topology()
  test_split_k_two_topologies()

class test.test_gcm_algorithm.ResampleJDS_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_manual_single_topology()

## test.test_joint_degree module

test.test_joint_degree.EECC_Test_util_network() → gcmpy.covers.EECC

class test.test_joint_degree.JDD_cover_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_EECC_cover()

class test.test_joint_degree.JDD_delta_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_delta_two_topologies()

class test.test_joint_degree.JDD_empirical_data_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_empirical_JDD_single_topology_list()
  test_empirical_JDD_single_topology_tuple()
  test_empirical_JDD_two_topology_list()
  test_empirical_JDD_two_topology_tuple()

class test.test_joint_degree.JDD_manual_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_manual_JDD_single_topology()
  test_manual_JDD_single_topology_performance()
  test_manual_JDD_two_topologies()

class test.test_joint_degree.JDD_marginal_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_marginal_JDD_many_topologies_sample()
  test_marginal_JDD_powerlaw_topology()
  test_marginal_JDD_scale_free_cut_off_topology()
  test_marginal_JDD_single_topology()
  test_marginal_JDD_two_topologies()
  test_marginal_JDD_two_topologies_sample()

class test.test_joint_degree.JDD_split_K_Test(methodName='runTest')

  Bases: `unittest.case.TestCase`

  test_split_k_two_topologies()

## test.test_utils module

## Module contents